<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>GrandSearch::BestMatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="22"/>
        <source>Best match</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GrandSearch::BlackListWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="26"/>
        <source>Excluded path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="37"/>
        <source>Add paths to the exclusion list to prevent searching in them.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GrandSearch::CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="26"/>
        <source>Custom search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GrandSearch::DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="42"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="85"/>
        <source>Grand Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="148"/>
        <source>Search settings</source>
        <translation>Nastavitve iskanja</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DeleteDialog</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="14"/>
        <source>Do you want to remove the path from the exclusion list?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="20"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="28"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="232"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="233"/>
        <source>What would you like to search for?</source>
        <translation>Kaj bi radi posikali?</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="78"/>
        <source>Cut</source>
        <translation>Izreži</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="82"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="86"/>
        <source>Paste</source>
        <translation>Prilepi</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="192"/>
        <source>Location:</source>
        <translation>Lokacija:</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="203"/>
        <source>Time modified:</source>
        <translation>Čas spreminjanja:</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="69"/>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="74"/>
        <source>Open Path</source>
        <translation>Odpri pot</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="79"/>
        <source>Copy Path</source>
        <translation>Kopiraj pot</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="288"/>
        <source>More</source>
        <translation>Več</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="324"/>
        <source>No search results</source>
        <translation type="unfinished">Ni rezultatov iskanja</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IndexWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/indexwidget.cpp" line="22"/>
        <source>Index</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GrandSearch::MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="208"/>
        <source>No search results</source>
        <translation>Ni rezultatov iskanja</translation>
    </message>
</context>
<context>
    <name>GrandSearch::PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="27"/>
        <source>Search experience program</source>
        <translation>Program uporabniške izkušnje iskanja</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="35"/>
        <source>Join search experience program</source>
        <translation>Pridružite se programu uporabniške izkušnje iskanja</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="48"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations, the contents you search while using the Application, the time of search, the type of requested large model.If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="59"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>Če želite izvedeti več o upravljanju vaših podatkov, preverite UnionTech Software pravilnik zasebnosti (</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="61"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-en</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="62"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/en/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
        <source>).</source>
        <translation>).</translation>
    </message>
</context>
<context>
    <name>GrandSearch::ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="28"/>
        <source>Search contents</source>
        <translation>Vsebine iskanj</translation>
    </message>
</context>
<context>
    <name>GrandSearch::SearchEngineWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="31"/>
        <source>Default search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="39"/>
        <source>Search for keywords by the default search engine.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="55"/>
        <source>Default search engine is</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="64"/>
        <source>Google</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="65"/>
        <source>Baidu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="66"/>
        <source>Bing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="67"/>
        <source>Yahoo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="68"/>
        <source>360</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="69"/>
        <source>Sogou</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GrandSearch::StaticTextWorker</name>
    <message>
        <location filename="../src/libgrand-search-daemon/searcher/web/statictextworker.cpp" line="53"/>
        <source>Search for &quot;%1&quot;</source>
        <translation>Poišči &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>GrandSearch::TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="18"/>
        <source>Tailer settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="28"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="41"/>
        <source>Parent directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
        <source>Time modified</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GrandSearch::audio_preview::AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="52"/>
        <source>Artist:</source>
        <translation>Izvajalec:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="64"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="85"/>
        <source>Duration:</source>
        <translation>Dolžina:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="100"/>
        <source>Type:</source>
        <translation>Vrsta:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="112"/>
        <source>Location:</source>
        <translation>Lokacija:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="126"/>
        <source>Time modified:</source>
        <translation>Čas spreminjanja:</translation>
    </message>
</context>
<context>
    <name>GrandSearch::image_preview::ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="53"/>
        <source>Dimensions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="69"/>
        <source>Type:</source>
        <translation>Vrsta:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="84"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="96"/>
        <source>Location:</source>
        <translation>Lokacija:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
        <source>Time modified:</source>
        <translation>Čas spreminjanja:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="24"/>
        <source>Best match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="25"/>
        <source>Applications</source>
        <translation>Aplikacije</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="26"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="27"/>
        <source>Videos</source>
        <translation>Videi</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="28"/>
        <source>Music</source>
        <translation>Glasba</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="29"/>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="30"/>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="31"/>
        <source>Folders</source>
        <translation>mape</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="32"/>
        <source>Files</source>
        <translation>Datoteke</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="33"/>
        <source>Web</source>
        <translation>Splet</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="34"/>
        <source>AI Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="19"/>
        <source>Dimensions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="20"/>
        <source>Type:</source>
        <translation>Vrsta:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="21"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="22"/>
        <source>Duration:</source>
        <translation>Dolžina:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="23"/>
        <source>Location:</source>
        <translation>Lokacija:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="24"/>
        <source>Time modified:</source>
        <translation>Čas spreminjanja:</translation>
    </message>
    <message>
        <location filename="../src/libgrand-search-daemon/searcher/file/filesearchutils.cpp" line="203"/>
        <source>modified</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
